#----------------------------------------------------------------
	## General Header Commands ##

# Pymol Script
# RO AUTOANTIGEN COMPLEXED WITH 2 RNAS     

# delete all objects and reset pymol
reinitialize

# set the background color to white
bg_color white

# make the background transparent for #ray trace 
set ray_opaque_background, 0

# set the ray trace mode
# normal color
set ray_trace_mode, 0
# normal color + black outline
#set ray_trace_mode,  1
# black outline only
#set ray_trace_mode,  2

# turn off shadows
set ray_shadows, 0

# set the mouse mode for laptop.
config_mouse one_button

# run the python program for hydrogen bonding interactions.
run files/python/list_hbonds.py
#------ put the python program list_hbonds.py
#------into the directory python.

#-----------------------------------------------------------------

load files/1yvp.pdb, ro_all
hide everything, ro_all

create ro, chain A and ro_all
show cartoon, ro 
set cartoon_cylindrical_helices,2, ro
color smudge, ss s
color blue, ss h
color wheat, ss l


create YRNA, (chain C or chain D) and ro_all
remove resn HOH and YRNA
show stick, YRNA
show cartoon, YRNA
set cartoon_ring_mode=3, YRNA
color wheat, name C* and (YRNA)
color red, name O* and (YRNA)
color blue, name N* and (YRNA)
color yellow, name P* and (YRNA)

label YRNA and name C1', resi+resn
set label_size, 18.0, YRNA
set label_color, deepteal, YRNA
set label_outline_color, black, YRNA
set label_shadow_mode=2, YRNA
set label_position, [1.3,1,2], YRNA


create YRNA_interface, byres((ro) within 3.4 of YRNA)
remove resn HOH and YRNA_interface
hide everything, YRNA_interface
show stick, YRNA_interface
color green, name C* and (YRNA_interface)
color red, name O* and (YRNA_interface)
color blue, name N* and (YRNA_interface)
color yellow, name P* and (YRNA_interface)

label YRNA_interface and name Ca, resi+resn
set label_size, 18.0, YRNA_interface
set label_color, deepteal, YRNA_interface
set label_outline_color, black, YRNA_interface
set label_shadow_mode=2, YRNA_interface
set label_position, [1.3,1,2], YRNA_interface

list_hb (YRNA), (YRNA_interface) , cutoff=3.4, angle = 80, hb_list_name = hb_ro-YRNA
color black, hb_ro-YRNA
set dash_width, 5, hb_ro-YRNA
set dash_gap, 0.2, hb_ro-YRNA

create 5SrRNA, (chain G) and ro_all
remove resn HOH and 5SrRNA
show stick, 5SrRNA
show cartoon, 5SrRNA
set cartoon_ring_mode=3, 5SrRNA
color wheat, name C* and (5SrRNA)
color red, name O* and (5SrRNA)
color blue, name N* and (5SrRNA)
color yellow, name P* and (5SrRNA)

label 5SrRNA and name C1', resi+resn
set label_size, 18.0, 5SrRNA
set label_color, deepteal, 5SrRNA
set label_outline_color, black, 5SrRNA
set label_shadow_mode=2, 5SrRNA
set label_position, [1.3,1,2], 5SrRNA


create 5SrRNA_interface, byres((ro) within 3.4 of 5SrRNA)
remove resn HOH and 5SrRNA_interface
hide everything, 5SrRNA_interface
show stick, 5SrRNA_interface
color green, name C* and (5SrRNA_interface)
color red, name O* and (5SrRNA_interface)
color blue, name N* and (5SrRNA_interface)
color yellow, name P* and (5SrRNA_interface)

label 5SrRNA_interface and name Ca, resi+resn
set label_size, 18.0, 5SrRNA_interface
set label_color, deepteal, 5SrRNA_interface
set label_outline_color, black, 5SrRNA_interface
set label_shadow_mode=2, 5SrRNA_interface
set label_position, [1.3,1,2], 5SrRNA_interface

list_hb (5SrRNA), (5SrRNA_interface) , cutoff=3.4, angle = 80, hb_list_name = hb_ro-5SrRNA
color black, hb_ro-5SrRNA
set dash_width, 5, hb_ro-5SrRNA
set dash_gap, 0.2, hb_ro-5SrRNA


create magnesium, resn Mg and ro
hide everything, magnesium
show nb_spheres, magnesium

label resn MG and magnesium, resn
set label_size, 18.0, magnesium
set label_color, deepteal, magnesium
set label_outline_color, black, magnesium
set label_shadow_mode=2, magnesium
set label_position, [1.3,1,2], magnesium

color orange, magnesium
create magnesium_a, byres((ro) within 2.6 of magnesium)
create magnesium_b, (resi 469+376+473+471 and ro)
show stick, magnesium_*
show nb_spheres, magnesium_*

distance magnesium_coordination, (magnesium), (magnesium_a and not resn Mg),  2.5
distance magnesium_coordination, (magnesium_a), (magnesium_b),  3.3
distance magnesium_coordination, resn act and magnesium_a, resi 445 and magnesium_a, 3.0
create magnesium_interface, magnesium_a and not resn MG + magnesium_b
delete magnesium_a 
delete magnesium_b
hide everything, magnesium_interface
show stick, magnesium_interface
show nb_spheres, magnesium_interface
color green, name C* and (magnesium_interface)
color red, name O* and (magnesium_interface)
color blue, name N* and (magnesium_interface)
color yellow, name P* and (magnesium_interface)
color wheat, name C* and resn act and (magnesium_interface)

color black, magnesium_coordination
set dash_width, 5, magnesium_coordination
set dash_gap, 0.2, magnesium_coordination

label magnesium_interface and name Ca, resi+resn
label magnesium_interface and name CH3, "acetate"
label magnesium_interface and resn HOH, "W"
set label_size, 18.0, magnesium_interface
set label_color, deepteal, magnesium_interface
set label_outline_color, black, magnesium_interface
set label_shadow_mode=2, magnesium_interface
set label_position, [1.3,1,2], magnesium_interface


disable all
enable ro
enable YRNA
enable 5SrRNA
delete ro_all

set_view (\
     0.261539489,   -0.747192800,    0.610982716,\
    -0.171791807,    0.586868763,    0.791247249,\
    -0.949782312,   -0.311904997,    0.025129404,\
    -0.000155013,   -0.000137717, -267.516479492,\
    17.374092102,   32.730255127,   51.885890961,\
   245.644027710,  289.412780762,  -20.000000000 )
   
#ray 2000,2000
#save  image_1.png



